;;; X11 color names converted to Snd colors

(provide 'snd-rgb.scm)

(define *rgb*
  (let ()

;; tan -> tawny 24-Aug-01

(define snow (make-color 1.00 0.98 0.98))
(define ghost-white (make-color 0.97 0.97 1.00))
(define white-smoke (make-color 0.96 0.96 0.96))
(define gainsboro (make-color 0.86 0.86 0.86))
(define floral-white (make-color 1.00 0.98 0.94))
(define old-lace (make-color 0.99 0.96 0.90))
(define linen (make-color 0.98 0.94 0.90))
(define antique-white (make-color 0.98 0.92 0.84))
(define papaya-whip (make-color 1.00 0.93 0.83))
(define blanched-almond (make-color 1.00 0.92 0.80))
(define bisque (make-color 1.00 0.89 0.77))
(define peach-puff (make-color 1.00 0.85 0.72))
(define navajo-white (make-color 1.00 0.87 0.68))
(define moccasin (make-color 1.00 0.89 0.71))
(define cornsilk (make-color 1.00 0.97 0.86))
(define ivory (make-color 1.00 1.00 0.94))
(define lemon-chiffon (make-color 1.00 0.98 0.80))
(define seashell (make-color 1.00 0.96 0.93))
(define honeydew (make-color 0.94 1.00 0.94))
(define mint-cream (make-color 0.96 1.00 0.98))
(define azure (make-color 0.94 1.00 1.00))
(define alice-blue (make-color 0.94 0.97 1.00))
(define lavender (make-color 0.90 0.90 0.98))
(define lavender-blush (make-color 1.00 0.94 0.96))
(define misty-rose (make-color 1.00 0.89 0.88))
(define white (make-color 1.00 1.00 1.00))
(define black (make-color 0.00 0.00 0.00))
(define dark-slate-gray (make-color 0.18 0.31 0.31))
(define dark-slate-grey (make-color 0.18 0.31 0.31))
(define dim-gray (make-color 0.41 0.41 0.41))
(define dim-grey (make-color 0.41 0.41 0.41))
(define slate-gray (make-color 0.44 0.50 0.56))
(define slate-grey (make-color 0.44 0.50 0.56))
(define light-slate-gray (make-color 0.46 0.53 0.60))
(define light-slate-grey (make-color 0.46 0.53 0.60))
(define gray (make-color 0.74 0.74 0.74))
(define grey (make-color 0.74 0.74 0.74))
(define light-grey (make-color 0.82 0.82 0.82))
(define light-gray (make-color 0.82 0.82 0.82))
(define midnight-blue (make-color 0.10 0.10 0.44))
(define navy (make-color 0.00 0.00 0.50))
(define navy-blue (make-color 0.00 0.00 0.50))
(define cornflower-blue (make-color 0.39 0.58 0.93))
(define dark-slate-blue (make-color 0.28 0.24 0.54))
(define slate-blue (make-color 0.41 0.35 0.80))
(define medium-slate-blue (make-color 0.48 0.41 0.93))
(define light-slate-blue (make-color 0.52 0.44 1.00))
(define medium-blue (make-color 0.00 0.00 0.80))
(define royal-blue (make-color 0.25 0.41 0.88))
(define blue (make-color 0.00 0.00 1.00))
(define dodger-blue (make-color 0.12 0.56 1.00))
(define deep-sky-blue (make-color 0.00 0.75 1.00))
(define sky-blue (make-color 0.53 0.80 0.92))
(define light-sky-blue (make-color 0.53 0.80 0.98))
(define steel-blue (make-color 0.27 0.51 0.70))
(define light-steel-blue (make-color 0.69 0.77 0.87))
(define light-blue (make-color 0.68 0.84 0.90))
(define powder-blue (make-color 0.69 0.87 0.90))
(define pale-turquoise (make-color 0.68 0.93 0.93))
(define dark-turquoise (make-color 0.00 0.80 0.82))
(define medium-turquoise (make-color 0.28 0.82 0.80))
(define turquoise (make-color 0.25 0.87 0.81))
(define cyan (make-color 0.00 1.00 1.00))
(define light-cyan (make-color 0.87 1.00 1.00))
(define cadet-blue (make-color 0.37 0.62 0.62))
(define medium-aquamarine (make-color 0.40 0.80 0.66))
(define aquamarine (make-color 0.50 1.00 0.83))
(define dark-green (make-color 0.00 0.39 0.00))
(define dark-olive-green (make-color 0.33 0.42 0.18))
(define dark-sea-green (make-color 0.56 0.73 0.56))
(define sea-green (make-color 0.18 0.54 0.34))
(define medium-sea-green (make-color 0.23 0.70 0.44))
(define light-sea-green (make-color 0.12 0.70 0.66))
(define pale-green (make-color 0.59 0.98 0.59))
(define spring-green (make-color 0.00 1.00 0.50))
(define lawn-green (make-color 0.48 0.98 0.00))
(define green (make-color 0.00 1.00 0.00))
(define chartreuse (make-color 0.50 1.00 0.00))
(define medium-spring-green (make-color 0.00 0.98 0.60))
(define green-yellow (make-color 0.68 1.00 0.18))
(define lime-green (make-color 0.20 0.80 0.20))
(define yellow-green (make-color 0.60 0.80 0.20))
(define forest-green (make-color 0.13 0.54 0.13))
(define olive-drab (make-color 0.42 0.55 0.14))
(define dark-khaki (make-color 0.74 0.71 0.42))
(define khaki (make-color 0.94 0.90 0.55))
(define pale-goldenrod (make-color 0.93 0.91 0.66))
(define light-goldenrod-yellow (make-color 0.98 0.98 0.82))
(define light-yellow (make-color 1.00 1.00 0.87))
(define yellow (make-color 1.00 1.00 0.00))
(define gold (make-color 1.00 0.84 0.00))
(define light-goldenrod (make-color 0.93 0.86 0.51))
(define goldenrod (make-color 0.85 0.64 0.12))
(define dark-goldenrod (make-color 0.72 0.52 0.04))
(define rosy-brown (make-color 0.73 0.56 0.56))
(define indian-red (make-color 0.80 0.36 0.36))
(define saddle-brown (make-color 0.54 0.27 0.07))
(define sienna (make-color 0.62 0.32 0.18))
(define peru (make-color 0.80 0.52 0.25))
(define burlywood (make-color 0.87 0.72 0.53))
(define beige (make-color 0.96 0.96 0.86))
(define wheat (make-color 0.96 0.87 0.70))
(define sandy-brown (make-color 0.95 0.64 0.37))
(define tawny (make-color 0.82 0.70 0.55)) ; tan collides with Scheme built-in -- tawny suggested by Dave Phillips
(define chocolate (make-color 0.82 0.41 0.12))
(define firebrick (make-color 0.70 0.13 0.13))
(define brown (make-color 0.64 0.16 0.16))
(define dark-salmon (make-color 0.91 0.59 0.48))
(define salmon (make-color 0.98 0.50 0.45))
(define light-salmon (make-color 1.00 0.62 0.48))
(define orange (make-color 1.00 0.64 0.00))
(define dark-orange (make-color 1.00 0.55 0.00))
(define coral (make-color 1.00 0.50 0.31))
(define light-coral (make-color 0.94 0.50 0.50))
(define tomato (make-color 1.00 0.39 0.28))
(define orange-red (make-color 1.00 0.27 0.00))
(define red (make-color 1.00 0.00 0.00))
(define hot-pink (make-color 1.00 0.41 0.70))
(define deep-pink (make-color 1.00 0.08 0.57))
(define pink (make-color 1.00 0.75 0.79))
(define light-pink (make-color 1.00 0.71 0.75))
(define pale-violet-red (make-color 0.86 0.44 0.57))
(define maroon (make-color 0.69 0.19 0.37))
(define medium-violet-red (make-color 0.78 0.08 0.52))
(define violet-red (make-color 0.81 0.12 0.56))
(define magenta (make-color 1.00 0.00 1.00))
(define violet (make-color 0.93 0.51 0.93))
(define plum (make-color 0.86 0.62 0.86))
(define orchid (make-color 0.85 0.44 0.84))
(define medium-orchid (make-color 0.73 0.33 0.82))
(define dark-orchid (make-color 0.60 0.20 0.80))
(define dark-violet (make-color 0.58 0.00 0.82))
(define blue-violet (make-color 0.54 0.17 0.88))
(define purple (make-color 0.62 0.12 0.94))
(define medium-purple (make-color 0.57 0.44 0.86))
(define thistle (make-color 0.84 0.75 0.84))
(define snow1 (make-color 1.00 0.98 0.98))
(define snow2 (make-color 0.93 0.91 0.91))
(define snow3 (make-color 0.80 0.79 0.79))
(define snow4 (make-color 0.54 0.54 0.54))
(define seashell1 (make-color 1.00 0.96 0.93))
(define seashell2 (make-color 0.93 0.89 0.87))
(define seashell3 (make-color 0.80 0.77 0.75))
(define seashell4 (make-color 0.54 0.52 0.51))
(define antiquewhite1 (make-color 1.00 0.93 0.86))
(define antiquewhite2 (make-color 0.93 0.87 0.80))
(define antiquewhite3 (make-color 0.80 0.75 0.69))
(define antiquewhite4 (make-color 0.54 0.51 0.47))
(define bisque1 (make-color 1.00 0.89 0.77))
(define bisque2 (make-color 0.93 0.83 0.71))
(define bisque3 (make-color 0.80 0.71 0.62))
(define bisque4 (make-color 0.54 0.49 0.42))
(define peachpuff1 (make-color 1.00 0.85 0.72))
(define peachpuff2 (make-color 0.93 0.79 0.68))
(define peachpuff3 (make-color 0.80 0.68 0.58))
(define peachpuff4 (make-color 0.54 0.46 0.39))
(define navajowhite1 (make-color 1.00 0.87 0.68))
(define navajowhite2 (make-color 0.93 0.81 0.63))
(define navajowhite3 (make-color 0.80 0.70 0.54))
(define navajowhite4 (make-color 0.54 0.47 0.37))
(define lemonchiffon1 (make-color 1.00 0.98 0.80))
(define lemonchiffon2 (make-color 0.93 0.91 0.75))
(define lemonchiffon3 (make-color 0.80 0.79 0.64))
(define lemonchiffon4 (make-color 0.54 0.54 0.44))
(define cornsilk1 (make-color 1.00 0.97 0.86))
(define cornsilk2 (make-color 0.93 0.91 0.80))
(define cornsilk3 (make-color 0.80 0.78 0.69))
(define cornsilk4 (make-color 0.54 0.53 0.47))
(define ivory1 (make-color 1.00 1.00 0.94))
(define ivory2 (make-color 0.93 0.93 0.87))
(define ivory3 (make-color 0.80 0.80 0.75))
(define ivory4 (make-color 0.54 0.54 0.51))
(define honeydew1 (make-color 0.94 1.00 0.94))
(define honeydew2 (make-color 0.87 0.93 0.87))
(define honeydew3 (make-color 0.75 0.80 0.75))
(define honeydew4 (make-color 0.51 0.54 0.51))
(define lavenderblush1 (make-color 1.00 0.94 0.96))
(define lavenderblush2 (make-color 0.93 0.87 0.89))
(define lavenderblush3 (make-color 0.80 0.75 0.77))
(define lavenderblush4 (make-color 0.54 0.51 0.52))
(define mistyrose1 (make-color 1.00 0.89 0.88))
(define mistyrose2 (make-color 0.93 0.83 0.82))
(define mistyrose3 (make-color 0.80 0.71 0.71))
(define mistyrose4 (make-color 0.54 0.49 0.48))
(define azure1 (make-color 0.94 1.00 1.00))
(define azure2 (make-color 0.87 0.93 0.93))
(define azure3 (make-color 0.75 0.80 0.80))
(define azure4 (make-color 0.51 0.54 0.54))
(define slateblue1 (make-color 0.51 0.43 1.00))
(define slateblue2 (make-color 0.48 0.40 0.93))
(define slateblue3 (make-color 0.41 0.35 0.80))
(define slateblue4 (make-color 0.28 0.23 0.54))
(define royalblue1 (make-color 0.28 0.46 1.00))
(define royalblue2 (make-color 0.26 0.43 0.93))
(define royalblue3 (make-color 0.23 0.37 0.80))
(define royalblue4 (make-color 0.15 0.25 0.54))
(define blue1 (make-color 0.00 0.00 1.00))
(define blue2 (make-color 0.00 0.00 0.93))
(define blue3 (make-color 0.00 0.00 0.80))
(define blue4 (make-color 0.00 0.00 0.54))
(define dodgerblue1 (make-color 0.12 0.56 1.00))
(define dodgerblue2 (make-color 0.11 0.52 0.93))
(define dodgerblue3 (make-color 0.09 0.45 0.80))
(define dodgerblue4 (make-color 0.06 0.30 0.54))
(define steelblue1 (make-color 0.39 0.72 1.00))
(define steelblue2 (make-color 0.36 0.67 0.93))
(define steelblue3 (make-color 0.31 0.58 0.80))
(define steelblue4 (make-color 0.21 0.39 0.54))
(define deepskyblue1 (make-color 0.00 0.75 1.00))
(define deepskyblue2 (make-color 0.00 0.70 0.93))
(define deepskyblue3 (make-color 0.00 0.60 0.80))
(define deepskyblue4 (make-color 0.00 0.41 0.54))
(define skyblue1 (make-color 0.53 0.80 1.00))
(define skyblue2 (make-color 0.49 0.75 0.93))
(define skyblue3 (make-color 0.42 0.65 0.80))
(define skyblue4 (make-color 0.29 0.44 0.54))
(define lightskyblue1 (make-color 0.69 0.88 1.00))
(define lightskyblue2 (make-color 0.64 0.82 0.93))
(define lightskyblue3 (make-color 0.55 0.71 0.80))
(define lightskyblue4 (make-color 0.37 0.48 0.54))
(define slategray1 (make-color 0.77 0.88 1.00))
(define slategray2 (make-color 0.72 0.82 0.93))
(define slategray3 (make-color 0.62 0.71 0.80))
(define slategray4 (make-color 0.42 0.48 0.54))
(define lightsteelblue1 (make-color 0.79 0.88 1.00))
(define lightsteelblue2 (make-color 0.73 0.82 0.93))
(define lightsteelblue3 (make-color 0.63 0.71 0.80))
(define lightsteelblue4 (make-color 0.43 0.48 0.54))
(define lightblue1 (make-color 0.75 0.93 1.00))
(define lightblue2 (make-color 0.70 0.87 0.93))
(define lightblue3 (make-color 0.60 0.75 0.80))
(define lightblue4 (make-color 0.41 0.51 0.54))
(define lightcyan1 (make-color 0.87 1.00 1.00))
(define lightcyan2 (make-color 0.82 0.93 0.93))
(define lightcyan3 (make-color 0.70 0.80 0.80))
(define lightcyan4 (make-color 0.48 0.54 0.54))
(define paleturquoise1 (make-color 0.73 1.00 1.00))
(define paleturquoise2 (make-color 0.68 0.93 0.93))
(define paleturquoise3 (make-color 0.59 0.80 0.80))
(define paleturquoise4 (make-color 0.40 0.54 0.54))
(define cadetblue1 (make-color 0.59 0.96 1.00))
(define cadetblue2 (make-color 0.55 0.89 0.93))
(define cadetblue3 (make-color 0.48 0.77 0.80))
(define cadetblue4 (make-color 0.32 0.52 0.54))
(define turquoise1 (make-color 0.00 0.96 1.00))
(define turquoise2 (make-color 0.00 0.89 0.93))
(define turquoise3 (make-color 0.00 0.77 0.80))
(define turquoise4 (make-color 0.00 0.52 0.54))
(define cyan1 (make-color 0.00 1.00 1.00))
(define cyan2 (make-color 0.00 0.93 0.93))
(define cyan3 (make-color 0.00 0.80 0.80))
(define cyan4 (make-color 0.00 0.54 0.54))
(define darkslategray1 (make-color 0.59 1.00 1.00))
(define darkslategray2 (make-color 0.55 0.93 0.93))
(define darkslategray3 (make-color 0.47 0.80 0.80))
(define darkslategray4 (make-color 0.32 0.54 0.54))
(define aquamarine1 (make-color 0.50 1.00 0.83))
(define aquamarine2 (make-color 0.46 0.93 0.77))
(define aquamarine3 (make-color 0.40 0.80 0.66))
(define aquamarine4 (make-color 0.27 0.54 0.45))
(define darkseagreen1 (make-color 0.75 1.00 0.75))
(define darkseagreen2 (make-color 0.70 0.93 0.70))
(define darkseagreen3 (make-color 0.61 0.80 0.61))
(define darkseagreen4 (make-color 0.41 0.54 0.41))
(define seagreen1 (make-color 0.33 1.00 0.62))
(define seagreen2 (make-color 0.30 0.93 0.58))
(define seagreen3 (make-color 0.26 0.80 0.50))
(define seagreen4 (make-color 0.18 0.54 0.34))
(define palegreen1 (make-color 0.60 1.00 0.60))
(define palegreen2 (make-color 0.56 0.93 0.56))
(define palegreen3 (make-color 0.48 0.80 0.48))
(define palegreen4 (make-color 0.33 0.54 0.33))
(define springgreen1 (make-color 0.00 1.00 0.50))
(define springgreen2 (make-color 0.00 0.93 0.46))
(define springgreen3 (make-color 0.00 0.80 0.40))
(define springgreen4 (make-color 0.00 0.54 0.27))
(define green1 (make-color 0.00 1.00 0.00))
(define green2 (make-color 0.00 0.93 0.00))
(define green3 (make-color 0.00 0.80 0.00))
(define green4 (make-color 0.00 0.54 0.00))
(define chartreuse1 (make-color 0.50 1.00 0.00))
(define chartreuse2 (make-color 0.46 0.93 0.00))
(define chartreuse3 (make-color 0.40 0.80 0.00))
(define chartreuse4 (make-color 0.27 0.54 0.00))
(define olivedrab1 (make-color 0.75 1.00 0.24))
(define olivedrab2 (make-color 0.70 0.93 0.23))
(define olivedrab3 (make-color 0.60 0.80 0.20))
(define olivedrab4 (make-color 0.41 0.54 0.13))
(define darkolivegreen1 (make-color 0.79 1.00 0.44))
(define darkolivegreen2 (make-color 0.73 0.93 0.41))
(define darkolivegreen3 (make-color 0.63 0.80 0.35))
(define darkolivegreen4 (make-color 0.43 0.54 0.24))
(define khaki1 (make-color 1.00 0.96 0.56))
(define khaki2 (make-color 0.93 0.90 0.52))
(define khaki3 (make-color 0.80 0.77 0.45))
(define khaki4 (make-color 0.54 0.52 0.30))
(define lightgoldenrod1 (make-color 1.00 0.92 0.54))
(define lightgoldenrod2 (make-color 0.93 0.86 0.51))
(define lightgoldenrod3 (make-color 0.80 0.74 0.44))
(define lightgoldenrod4 (make-color 0.54 0.50 0.30))
(define lightyellow1 (make-color 1.00 1.00 0.87))
(define lightyellow2 (make-color 0.93 0.93 0.82))
(define lightyellow3 (make-color 0.80 0.80 0.70))
(define lightyellow4 (make-color 0.54 0.54 0.48))
(define yellow1 (make-color 1.00 1.00 0.00))
(define yellow2 (make-color 0.93 0.93 0.00))
(define yellow3 (make-color 0.80 0.80 0.00))
(define yellow4 (make-color 0.54 0.54 0.00))
(define gold1 (make-color 1.00 0.84 0.00))
(define gold2 (make-color 0.93 0.79 0.00))
(define gold3 (make-color 0.80 0.68 0.00))
(define gold4 (make-color 0.54 0.46 0.00))
(define goldenrod1 (make-color 1.00 0.75 0.14))
(define goldenrod2 (make-color 0.93 0.70 0.13))
(define goldenrod3 (make-color 0.80 0.61 0.11))
(define goldenrod4 (make-color 0.54 0.41 0.08))
(define darkgoldenrod1 (make-color 1.00 0.72 0.06))
(define darkgoldenrod2 (make-color 0.93 0.68 0.05))
(define darkgoldenrod3 (make-color 0.80 0.58 0.05))
(define darkgoldenrod4 (make-color 0.54 0.39 0.03))
(define rosybrown1 (make-color 1.00 0.75 0.75))
(define rosybrown2 (make-color 0.93 0.70 0.70))
(define rosybrown3 (make-color 0.80 0.61 0.61))
(define rosybrown4 (make-color 0.54 0.41 0.41))
(define indianred1 (make-color 1.00 0.41 0.41))
(define indianred2 (make-color 0.93 0.39 0.39))
(define indianred3 (make-color 0.80 0.33 0.33))
(define indianred4 (make-color 0.54 0.23 0.23))
(define sienna1 (make-color 1.00 0.51 0.28))
(define sienna2 (make-color 0.93 0.47 0.26))
(define sienna3 (make-color 0.80 0.41 0.22))
(define sienna4 (make-color 0.54 0.28 0.15))
(define burlywood1 (make-color 1.00 0.82 0.61))
(define burlywood2 (make-color 0.93 0.77 0.57))
(define burlywood3 (make-color 0.80 0.66 0.49))
(define burlywood4 (make-color 0.54 0.45 0.33))
(define wheat1 (make-color 1.00 0.90 0.73))
(define wheat2 (make-color 0.93 0.84 0.68))
(define wheat3 (make-color 0.80 0.73 0.59))
(define wheat4 (make-color 0.54 0.49 0.40))
(define tan1 (make-color 1.00 0.64 0.31))
(define tan2 (make-color 0.93 0.60 0.29))
(define tan3 (make-color 0.80 0.52 0.25))
(define tan4 (make-color 0.54 0.35 0.17))
(define chocolate1 (make-color 1.00 0.50 0.14))
(define chocolate2 (make-color 0.93 0.46 0.13))
(define chocolate3 (make-color 0.80 0.40 0.11))
(define chocolate4 (make-color 0.54 0.27 0.07))
(define firebrick1 (make-color 1.00 0.19 0.19))
(define firebrick2 (make-color 0.93 0.17 0.17))
(define firebrick3 (make-color 0.80 0.15 0.15))
(define firebrick4 (make-color 0.54 0.10 0.10))
(define brown1 (make-color 1.00 0.25 0.25))
(define brown2 (make-color 0.93 0.23 0.23))
(define brown3 (make-color 0.80 0.20 0.20))
(define brown4 (make-color 0.54 0.14 0.14))
(define salmon1 (make-color 1.00 0.55 0.41))
(define salmon2 (make-color 0.93 0.51 0.38))
(define salmon3 (make-color 0.80 0.44 0.33))
(define salmon4 (make-color 0.54 0.30 0.22))
(define lightsalmon1 (make-color 1.00 0.62 0.48))
(define lightsalmon2 (make-color 0.93 0.58 0.45))
(define lightsalmon3 (make-color 0.80 0.50 0.38))
(define lightsalmon4 (make-color 0.54 0.34 0.26))
(define orange1 (make-color 1.00 0.64 0.00))
(define orange2 (make-color 0.93 0.60 0.00))
(define orange3 (make-color 0.80 0.52 0.00))
(define orange4 (make-color 0.54 0.35 0.00))
(define darkorange1 (make-color 1.00 0.50 0.00))
(define darkorange2 (make-color 0.93 0.46 0.00))
(define darkorange3 (make-color 0.80 0.40 0.00))
(define darkorange4 (make-color 0.54 0.27 0.00))
(define coral1 (make-color 1.00 0.45 0.34))
(define coral2 (make-color 0.93 0.41 0.31))
(define coral3 (make-color 0.80 0.36 0.27))
(define coral4 (make-color 0.54 0.24 0.18))
(define tomato1 (make-color 1.00 0.39 0.28))
(define tomato2 (make-color 0.93 0.36 0.26))
(define tomato3 (make-color 0.80 0.31 0.22))
(define tomato4 (make-color 0.54 0.21 0.15))
(define orangered1 (make-color 1.00 0.27 0.00))
(define orangered2 (make-color 0.93 0.25 0.00))
(define orangered3 (make-color 0.80 0.21 0.00))
(define orangered4 (make-color 0.54 0.14 0.00))
(define red1 (make-color 1.00 0.00 0.00))
(define red2 (make-color 0.93 0.00 0.00))
(define red3 (make-color 0.80 0.00 0.00))
(define red4 (make-color 0.54 0.00 0.00))
(define deeppink1 (make-color 1.00 0.08 0.57))
(define deeppink2 (make-color 0.93 0.07 0.54))
(define deeppink3 (make-color 0.80 0.06 0.46))
(define deeppink4 (make-color 0.54 0.04 0.31))
(define hotpink1 (make-color 1.00 0.43 0.70))
(define hotpink2 (make-color 0.93 0.41 0.65))
(define hotpink3 (make-color 0.80 0.37 0.56))
(define hotpink4 (make-color 0.54 0.23 0.38))
(define pink1 (make-color 1.00 0.71 0.77))
(define pink2 (make-color 0.93 0.66 0.72))
(define pink3 (make-color 0.80 0.57 0.62))
(define pink4 (make-color 0.54 0.39 0.42))
(define lightpink1 (make-color 1.00 0.68 0.72))
(define lightpink2 (make-color 0.93 0.63 0.68))
(define lightpink3 (make-color 0.80 0.55 0.58))
(define lightpink4 (make-color 0.54 0.37 0.39))
(define palevioletred1 (make-color 1.00 0.51 0.67))
(define palevioletred2 (make-color 0.93 0.47 0.62))
(define palevioletred3 (make-color 0.80 0.41 0.54))
(define palevioletred4 (make-color 0.54 0.28 0.36))
(define maroon1 (make-color 1.00 0.20 0.70))
(define maroon2 (make-color 0.93 0.19 0.65))
(define maroon3 (make-color 0.80 0.16 0.56))
(define maroon4 (make-color 0.54 0.11 0.38))
(define violetred1 (make-color 1.00 0.24 0.59))
(define violetred2 (make-color 0.93 0.23 0.55))
(define violetred3 (make-color 0.80 0.20 0.47))
(define violetred4 (make-color 0.54 0.13 0.32))
(define magenta1 (make-color 1.00 0.00 1.00))
(define magenta2 (make-color 0.93 0.00 0.93))
(define magenta3 (make-color 0.80 0.00 0.80))
(define magenta4 (make-color 0.54 0.00 0.54))
(define orchid1 (make-color 1.00 0.51 0.98))
(define orchid2 (make-color 0.93 0.48 0.91))
(define orchid3 (make-color 0.80 0.41 0.79))
(define orchid4 (make-color 0.54 0.28 0.54))
(define plum1 (make-color 1.00 0.73 1.00))
(define plum2 (make-color 0.93 0.68 0.93))
(define plum3 (make-color 0.80 0.59 0.80))
(define plum4 (make-color 0.54 0.40 0.54))
(define mediumorchid1 (make-color 0.87 0.40 1.00))
(define mediumorchid2 (make-color 0.82 0.37 0.93))
(define mediumorchid3 (make-color 0.70 0.32 0.80))
(define mediumorchid4 (make-color 0.48 0.21 0.54))
(define darkorchid1 (make-color 0.75 0.24 1.00))
(define darkorchid2 (make-color 0.70 0.23 0.93))
(define darkorchid3 (make-color 0.60 0.20 0.80))
(define darkorchid4 (make-color 0.41 0.13 0.54))
(define purple1 (make-color 0.61 0.19 1.00))
(define purple2 (make-color 0.57 0.17 0.93))
(define purple3 (make-color 0.49 0.15 0.80))
(define purple4 (make-color 0.33 0.10 0.54))
(define mediumpurple1 (make-color 0.67 0.51 1.00))
(define mediumpurple2 (make-color 0.62 0.47 0.93))
(define mediumpurple3 (make-color 0.54 0.41 0.80))
(define mediumpurple4 (make-color 0.36 0.28 0.54))
(define thistle1 (make-color 1.00 0.88 1.00))
(define thistle2 (make-color 0.93 0.82 0.93))
(define thistle3 (make-color 0.80 0.71 0.80))
(define thistle4 (make-color 0.54 0.48 0.54))
(define gray0 (make-color 0.00 0.00 0.00))
(define grey0 (make-color 0.00 0.00 0.00))
(define gray1 (make-color 0.01 0.01 0.01))
(define grey1 (make-color 0.01 0.01 0.01))
(define gray2 (make-color 0.02 0.02 0.02))
(define grey2 (make-color 0.02 0.02 0.02))
(define gray3 (make-color 0.03 0.03 0.03))
(define grey3 (make-color 0.03 0.03 0.03))
(define gray4 (make-color 0.04 0.04 0.04))
(define grey4 (make-color 0.04 0.04 0.04))
(define gray5 (make-color 0.05 0.05 0.05))
(define grey5 (make-color 0.05 0.05 0.05))
(define gray6 (make-color 0.06 0.06 0.06))
(define grey6 (make-color 0.06 0.06 0.06))
(define gray7 (make-color 0.07 0.07 0.07))
(define grey7 (make-color 0.07 0.07 0.07))
(define gray8 (make-color 0.08 0.08 0.08))
(define grey8 (make-color 0.08 0.08 0.08))
(define gray9 (make-color 0.09 0.09 0.09))
(define grey9 (make-color 0.09 0.09 0.09))
(define gray10 (make-color 0.10 0.10 0.10))
(define grey10 (make-color 0.10 0.10 0.10))
(define gray11 (make-color 0.11 0.11 0.11))
(define grey11 (make-color 0.11 0.11 0.11))
(define gray12 (make-color 0.12 0.12 0.12))
(define grey12 (make-color 0.12 0.12 0.12))
(define gray13 (make-color 0.13 0.13 0.13))
(define grey13 (make-color 0.13 0.13 0.13))
(define gray14 (make-color 0.14 0.14 0.14))
(define grey14 (make-color 0.14 0.14 0.14))
(define gray15 (make-color 0.15 0.15 0.15))
(define grey15 (make-color 0.15 0.15 0.15))
(define gray16 (make-color 0.16 0.16 0.16))
(define grey16 (make-color 0.16 0.16 0.16))
(define gray17 (make-color 0.17 0.17 0.17))
(define grey17 (make-color 0.17 0.17 0.17))
(define gray18 (make-color 0.18 0.18 0.18))
(define grey18 (make-color 0.18 0.18 0.18))
(define gray19 (make-color 0.19 0.19 0.19))
(define grey19 (make-color 0.19 0.19 0.19))
(define gray20 (make-color 0.20 0.20 0.20))
(define grey20 (make-color 0.20 0.20 0.20))
(define gray21 (make-color 0.21 0.21 0.21))
(define grey21 (make-color 0.21 0.21 0.21))
(define gray22 (make-color 0.22 0.22 0.22))
(define grey22 (make-color 0.22 0.22 0.22))
(define gray23 (make-color 0.23 0.23 0.23))
(define grey23 (make-color 0.23 0.23 0.23))
(define gray24 (make-color 0.24 0.24 0.24))
(define grey24 (make-color 0.24 0.24 0.24))
(define gray25 (make-color 0.25 0.25 0.25))
(define grey25 (make-color 0.25 0.25 0.25))
(define gray26 (make-color 0.26 0.26 0.26))
(define grey26 (make-color 0.26 0.26 0.26))
(define gray27 (make-color 0.27 0.27 0.27))
(define grey27 (make-color 0.27 0.27 0.27))
(define gray28 (make-color 0.28 0.28 0.28))
(define grey28 (make-color 0.28 0.28 0.28))
(define gray29 (make-color 0.29 0.29 0.29))
(define grey29 (make-color 0.29 0.29 0.29))
(define gray30 (make-color 0.30 0.30 0.30))
(define grey30 (make-color 0.30 0.30 0.30))
(define gray31 (make-color 0.31 0.31 0.31))
(define grey31 (make-color 0.31 0.31 0.31))
(define gray32 (make-color 0.32 0.32 0.32))
(define grey32 (make-color 0.32 0.32 0.32))
(define gray33 (make-color 0.33 0.33 0.33))
(define grey33 (make-color 0.33 0.33 0.33))
(define gray34 (make-color 0.34 0.34 0.34))
(define grey34 (make-color 0.34 0.34 0.34))
(define gray35 (make-color 0.35 0.35 0.35))
(define grey35 (make-color 0.35 0.35 0.35))
(define gray36 (make-color 0.36 0.36 0.36))
(define grey36 (make-color 0.36 0.36 0.36))
(define gray37 (make-color 0.37 0.37 0.37))
(define grey37 (make-color 0.37 0.37 0.37))
(define gray38 (make-color 0.38 0.38 0.38))
(define grey38 (make-color 0.38 0.38 0.38))
(define gray39 (make-color 0.39 0.39 0.39))
(define grey39 (make-color 0.39 0.39 0.39))
(define gray40 (make-color 0.40 0.40 0.40))
(define grey40 (make-color 0.40 0.40 0.40))
(define gray41 (make-color 0.41 0.41 0.41))
(define grey41 (make-color 0.41 0.41 0.41))
(define gray42 (make-color 0.42 0.42 0.42))
(define grey42 (make-color 0.42 0.42 0.42))
(define gray43 (make-color 0.43 0.43 0.43))
(define grey43 (make-color 0.43 0.43 0.43))
(define gray44 (make-color 0.44 0.44 0.44))
(define grey44 (make-color 0.44 0.44 0.44))
(define gray45 (make-color 0.45 0.45 0.45))
(define grey45 (make-color 0.45 0.45 0.45))
(define gray46 (make-color 0.46 0.46 0.46))
(define grey46 (make-color 0.46 0.46 0.46))
(define gray47 (make-color 0.47 0.47 0.47))
(define grey47 (make-color 0.47 0.47 0.47))
(define gray48 (make-color 0.48 0.48 0.48))
(define grey48 (make-color 0.48 0.48 0.48))
(define gray49 (make-color 0.49 0.49 0.49))
(define grey49 (make-color 0.49 0.49 0.49))
(define gray50 (make-color 0.50 0.50 0.50))
(define grey50 (make-color 0.50 0.50 0.50))
(define gray51 (make-color 0.51 0.51 0.51))
(define grey51 (make-color 0.51 0.51 0.51))
(define gray52 (make-color 0.52 0.52 0.52))
(define grey52 (make-color 0.52 0.52 0.52))
(define gray53 (make-color 0.53 0.53 0.53))
(define grey53 (make-color 0.53 0.53 0.53))
(define gray54 (make-color 0.54 0.54 0.54))
(define grey54 (make-color 0.54 0.54 0.54))
(define gray55 (make-color 0.55 0.55 0.55))
(define grey55 (make-color 0.55 0.55 0.55))
(define gray56 (make-color 0.56 0.56 0.56))
(define grey56 (make-color 0.56 0.56 0.56))
(define gray57 (make-color 0.57 0.57 0.57))
(define grey57 (make-color 0.57 0.57 0.57))
(define gray58 (make-color 0.58 0.58 0.58))
(define grey58 (make-color 0.58 0.58 0.58))
(define gray59 (make-color 0.59 0.59 0.59))
(define grey59 (make-color 0.59 0.59 0.59))
(define gray60 (make-color 0.60 0.60 0.60))
(define grey60 (make-color 0.60 0.60 0.60))
(define gray61 (make-color 0.61 0.61 0.61))
(define grey61 (make-color 0.61 0.61 0.61))
(define gray62 (make-color 0.62 0.62 0.62))
(define grey62 (make-color 0.62 0.62 0.62))
(define gray63 (make-color 0.63 0.63 0.63))
(define grey63 (make-color 0.63 0.63 0.63))
(define gray64 (make-color 0.64 0.64 0.64))
(define grey64 (make-color 0.64 0.64 0.64))
(define gray65 (make-color 0.65 0.65 0.65))
(define grey65 (make-color 0.65 0.65 0.65))
(define gray66 (make-color 0.66 0.66 0.66))
(define grey66 (make-color 0.66 0.66 0.66))
(define gray67 (make-color 0.67 0.67 0.67))
(define grey67 (make-color 0.67 0.67 0.67))
(define gray68 (make-color 0.68 0.68 0.68))
(define grey68 (make-color 0.68 0.68 0.68))
(define gray69 (make-color 0.69 0.69 0.69))
(define grey69 (make-color 0.69 0.69 0.69))
(define gray70 (make-color 0.70 0.70 0.70))
(define grey70 (make-color 0.70 0.70 0.70))
(define gray71 (make-color 0.71 0.71 0.71))
(define grey71 (make-color 0.71 0.71 0.71))
(define gray72 (make-color 0.72 0.72 0.72))
(define grey72 (make-color 0.72 0.72 0.72))
(define gray73 (make-color 0.73 0.73 0.73))
(define grey73 (make-color 0.73 0.73 0.73))
(define gray74 (make-color 0.74 0.74 0.74))
(define grey74 (make-color 0.74 0.74 0.74))
(define gray75 (make-color 0.75 0.75 0.75))
(define grey75 (make-color 0.75 0.75 0.75))
(define gray76 (make-color 0.76 0.76 0.76))
(define grey76 (make-color 0.76 0.76 0.76))
(define gray77 (make-color 0.77 0.77 0.77))
(define grey77 (make-color 0.77 0.77 0.77))
(define gray78 (make-color 0.78 0.78 0.78))
(define grey78 (make-color 0.78 0.78 0.78))
(define gray79 (make-color 0.79 0.79 0.79))
(define grey79 (make-color 0.79 0.79 0.79))
(define gray80 (make-color 0.80 0.80 0.80))
(define grey80 (make-color 0.80 0.80 0.80))
(define gray81 (make-color 0.81 0.81 0.81))
(define grey81 (make-color 0.81 0.81 0.81))
(define gray82 (make-color 0.82 0.82 0.82))
(define grey82 (make-color 0.82 0.82 0.82))
(define gray83 (make-color 0.83 0.83 0.83))
(define grey83 (make-color 0.83 0.83 0.83))
(define gray84 (make-color 0.84 0.84 0.84))
(define grey84 (make-color 0.84 0.84 0.84))
(define gray85 (make-color 0.85 0.85 0.85))
(define grey85 (make-color 0.85 0.85 0.85))
(define gray86 (make-color 0.86 0.86 0.86))
(define grey86 (make-color 0.86 0.86 0.86))
(define gray87 (make-color 0.87 0.87 0.87))
(define grey87 (make-color 0.87 0.87 0.87))
(define gray88 (make-color 0.87 0.87 0.87))
(define grey88 (make-color 0.87 0.87 0.87))
(define gray89 (make-color 0.89 0.89 0.89))
(define grey89 (make-color 0.89 0.89 0.89))
(define gray90 (make-color 0.89 0.89 0.89))
(define grey90 (make-color 0.89 0.89 0.89))
(define gray91 (make-color 0.91 0.91 0.91))
(define grey91 (make-color 0.91 0.91 0.91))
(define gray92 (make-color 0.92 0.92 0.92))
(define grey92 (make-color 0.92 0.92 0.92))
(define gray93 (make-color 0.93 0.93 0.93))
(define grey93 (make-color 0.93 0.93 0.93))
(define gray94 (make-color 0.94 0.94 0.94))
(define grey94 (make-color 0.94 0.94 0.94))
(define gray95 (make-color 0.95 0.95 0.95))
(define grey95 (make-color 0.95 0.95 0.95))
(define gray96 (make-color 0.96 0.96 0.96))
(define grey96 (make-color 0.96 0.96 0.96))
(define gray97 (make-color 0.96 0.96 0.96))
(define grey97 (make-color 0.96 0.96 0.96))
(define gray98 (make-color 0.98 0.98 0.98))
(define grey98 (make-color 0.98 0.98 0.98))
(define gray99 (make-color 0.98 0.98 0.98))
(define grey99 (make-color 0.98 0.98 0.98))
(define gray100 (make-color 1.00 1.00 1.00))
(define grey100 (make-color 1.00 1.00 1.00))
(define dark-grey (make-color 0.66 0.66 0.66))
(define dark-gray (make-color 0.66 0.66 0.66))
(define dark-blue (make-color 0.00 0.00 0.54))
(define dark-cyan (make-color 0.00 0.54 0.54))
(define dark-magenta (make-color 0.54 0.00 0.54))
(define dark-red (make-color 0.54 0.00 0.00))
(define light-green (make-color 0.56 0.93 0.56))

(curlet)))
